==> ordering-core-0.1.6.tgz: package/lib/esm/mainService.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as listener from './wsListener';
import * as orderService from './orderService';
import * as orderStore from './orderStore';
export function orderChangesListener(BASE_URL, TENANT, VENUE, authDataProvider, refreshTokenHandler, onOrderUpdatedCallback, _onAuthFailureCallback) {
    return new Promise((resolve, reject) => {
        orderStore.setOrderStoreUpdatedCallback(onOrderUpdatedCallback);
        const params = {
            baseURL: BASE_URL,
            tenant: TENANT,
            venue: VENUE,
            authDataProvider: authDataProvider,
            refreshTokenHandler,
            onConnectedAsync: (accessToken) => __awaiter(this, void 0, void 0, function* () {
                console.log('ws connected!');
                const orders = yield orderService.pullOrdersForUser(BASE_URL, 
                //VENUE,
                accessToken);
                for (const order of orders) {
                    orderStore.onOrderUpdate(order);
                }
                resolve();
            }),
            onDisconnectAsync: () => __awaiter(this, void 0, void 0, function* () {
                console.log('ws disconnected');
            }),
            onKDSMessageAsync: null,
            // onKDSMessageAsync: async (message: any): Promise<void> => {
            //   console.log(`MESSAGE  order [${message.id}]`);
            //   orderStore.onOrderUpdate(message);
            // },
            onOrdersUpdateAsync: (order) => __awaiter(this, void 0, void 0, function* () {
                console.log(`new or updated order [${order.id}]`);
                orderStore.onOrderUpdate(order);
            }),
            onNotificationAsync: (message) => __awaiter(this, void 0, void 0, function* () {
                orderStore.onOrderError(message);
                console.log(`NOTIFICATION: ${JSON.stringify(message)}`);
            }),
            onAuthFailure: () => __awaiter(this, void 0, void 0, function* () {
                console.log('------------- MANUAL AUTH REQUIRED ----------------- ');
                if (_onAuthFailureCallback)
                    yield _onAuthFailureCallback();
            }),
        };
        listener.connectWebSockets(params);
    });
}

==> ordering-core-0.1.12.tgz: package/lib/esm/mainService.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as listener from './wsListener';
import * as orderService from './orderService';
import * as orderStore from './orderStore';
export function orderChangesListener(BASE_URL, TENANT, VENUE, authDataProvider, refreshTokenHandler, onOrderUpdatedCallback, _onAuthFailureCallback) {
    return new Promise((resolve, reject) => {
        orderStore.setOrderStoreUpdatedCallback(onOrderUpdatedCallback);
        const params = {
            baseURL: BASE_URL,
            tenant: TENANT,
            venue: VENUE,
            authDataProvider: authDataProvider,
            refreshTokenHandler,
            onConnectedAsync: (accessToken) => __awaiter(this, void 0, void 0, function* () {
                //console.log('ws connected!');
                const orders = yield orderService.pullOrdersForUser(BASE_URL, 
                //VENUE,
                accessToken);
                for (const order of orders) {
                    orderStore.onOrderUpdate(order);
                }
                resolve();
            }),
            onDisconnectAsync: () => __awaiter(this, void 0, void 0, function* () {
                //console.log('ws disconnected');
            }),
            onKDSMessageAsync: null,
            // onKDSMessageAsync: async (message: any): Promise<void> => {
            //   console.log(`MESSAGE  order [${message.id}]`);
            //   orderStore.onOrderUpdate(message);
            // },
            onOrdersUpdateAsync: (order) => __awaiter(this, void 0, void 0, function* () {
                console.log(`new or updated order [${order.id}]`);
                orderStore.onOrderUpdate(order);
            }),
            onNotificationAsync: (message) => __awaiter(this, void 0, void 0, function* () {
                orderStore.onOrderError(message);
                console.log(`NOTIFICATION: ${JSON.stringify(message)}`);
            }),
            onAuthFailure: () => __awaiter(this, void 0, void 0, function* () {
                console.log('------------- MANUAL AUTH REQUIRED ----------------- ');
                if (_onAuthFailureCallback)
                    yield _onAuthFailureCallback();
            }),
        };
        listener.connectWebSockets(params);
    });
}
